@@ -6,6 +6,8 @@
 """
 __docformat__ = "restructuredtext en"
 
+import json
+
 from logilab.common.decorators import cached
 from logilab.common.date import todate
 
@@ -15,6 +17,7 @@ from cubicweb import ValidationError
 from cubicweb.entities import AnyEntity
 from cubicweb.entities.adapters import IUserFriendlyUniqueTogether
 from cubicweb.selectors import is_instance
+from cubicweb.utils import CubicWebJsonEncoder
 
 from cubes.iprogress.entities import IProgressAdapter
 
@@ -49,7 +52,7 @@ class VersionIMileStoneAdapter(VersionIProgressAdapter):
     parent_type = 'Project'
 
     def contractors(self):
-        return self.entity.todo_by
+        return self.entity.assigned_to
 
     def in_progress(self):
         return self.entity.cw_adapt_to('IWorkflowable').state in self.entity.PROGRESSING_STATES
@@ -171,6 +174,11 @@ class Version(AnyEntity):
             return todate(rset[0][0])
         return None
 
+    def __json_encode__(self):
+        data = super(Version, self).__json_encode__()
+        data['state'] = self.cw_adapt_to('IWorkflowable').state
+        return json.dumps(data, cls=CubicWebJsonEncoder)
+
 
 class VersionIUserFriendlyUniqueTogether(IUserFriendlyUniqueTogether):
     __select__ = IUserFriendlyUniqueTogether.__select__ & is_instance('Version')
