@@ -1,3 +1,12 @@
+"""facets to search content
+
+:organization: Logilab
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
+"""
+__docformat__ = "restructuredtext en"
+_ = unicode
+
 from cubicweb.selectors import is_instance
 from cubicweb.web.facet import RelationFacet, AttributeFacet, DateRangeFacet
 
